summaryrefslogtreecommitdiffstats
path: root/src/Authoring/Studio/UI
diff options
context:
space:
mode:
authorMiikka Heikkinen <miikka.heikkinen@qt.io>2018-10-01 17:53:48 +0300
committerMiikka Heikkinen <miikka.heikkinen@qt.io>2018-10-03 07:54:28 +0000
commitb7460ca1068e4016fc7142fa58b868e21543e19f (patch)
tree424fb7050abab7017e7496412a5de436af01e40d /src/Authoring/Studio/UI
parent13cce3ca8b79cec5a396f2663bfafd19569d8265 (diff)
Show presentation ID in project palette
If presentation is not part of the project, a warning icon is shown instead of ID. Editing the ID of such presentation adds it to the project. Also made initial expanding of presentations folder work more reliably. Task-number: QT3DS-2231 Change-Id: I2dd4fbc3b3dbb3b18feb9fab88621e23d175c856 Reviewed-by: Mahmoud Badri <mahmoud.badri@qt.io> Reviewed-by: Tomi Korpipää <tomi.korpipaa@qt.io>
Diffstat (limited to 'src/Authoring/Studio/UI')
-rw-r--r--src/Authoring/Studio/UI/StudioProjectSettingsPage.cpp6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/Authoring/Studio/UI/StudioProjectSettingsPage.cpp b/src/Authoring/Studio/UI/StudioProjectSettingsPage.cpp
index 838f3ced..b8a15de5 100644
--- a/src/Authoring/Studio/UI/StudioProjectSettingsPage.cpp
+++ b/src/Authoring/Studio/UI/StudioProjectSettingsPage.cpp
@@ -176,7 +176,11 @@ void CStudioProjectSettingsPage::onSettingsModified()
// OnApply: Handler for the Apply button
bool CStudioProjectSettingsPage::onApply()
{
- // make sure the presentation Id is unique
+ // make sure the presentation Id is unique and not empty
+ if (m_ui->m_PresentationId->text().isEmpty()) {
+ g_StudioApp.showPresentationIdEmptyWarning();
+ return false;
+ }
if (!g_StudioApp.GetCore()->getProjectFile()
.isUniquePresentationId(m_ui->m_PresentationId->text())) {
g_StudioApp.showPresentationIdUniqueWarning();